Examples — pySciSci 0.6 documentation

# Examples

## Getting Started Examples

- Getting Started With OpenAlex

- Getting Started With MAG

- Getting Started With WoS

- Getting Started With DBLP

- Getting Started With APS

- Getting Started With PubMed

- Getting Started With Custom DB

- The Growth of Science

## Method Examples

- The Diffusion of Scientific Credit

- Credit Allocation

- Interdisciplinarity

- Novelty and Conventionality

- Cocitation Network

- Methods for Publication Impact

- Career Analysis

- Career Topic Switching

- Field Reference Strength

- Node2Vec Coauthorship

- CoWord Network

## Advanced Functionality

- Using Dask

- Working from a publication List

## Science of Science Textbook

Examples taken from different chapters of the Science of Science Textbook [2]. - Chapter 0 Data Prep - Chapter 1 Productivity of a Scientist - Chapter 2 The HIndex - Chapter 5 The Random Impact Rule - Chapter 6 The Qfactor - Chapter 14 Credit Allocation